abacusai.use_case — AbacusAI documentation

# abacusai.use_case

## Classes

`UseCase` | A Project Use Case

## Module Contents

class abacusai.use_case.UseCase(client, useCase=None, prettyName=None, description=None, problemType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Project Use Case

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - useCase (str) – The enum value for this use case

    - prettyName (str) – A user-friendly name

    - description (str) – A description for this use case

    - problemType (str) – Name for the underlying problem type

  use_case
  pretty_name
  description
  problem_type
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict